<div align="center">

<img src="lamassu-logo.png" width="30%"/>

</div>

[![Apache License badge]][Apache License URL]

Lamassu
=======

Lamassu is a project that empowers individual to agnostically run machine learning algorithms to produce ad-hoc NLP
features. **It's in beta development phase for the moment**.

License
-------

The use and distribution terms for Lamassu are covered by the
[Apache License, Version 2.0][Apache License, Version 2.0].

<div align="center">
    <a href="https://opensource.org/licenses">
        <img align="center" width="50%" alt="License Illustration" src="https://github.com/QubitPi/QubitPi/blob/master/img/apache-2.png?raw=true">
    </a>
</div>

[Apache License badge]: https://img.shields.io/badge/Apache%202.0-F25910.svg?style=for-the-badge&logo=Apache&logoColor=white
[Apache License URL]: https://www.apache.org/licenses/LICENSE-2.0
[Apache License, Version 2.0]: http://www.apache.org/licenses/LICENSE-2.0.html
